@@ -3,14 +3,11 @@ from .intcolumn import FormatColumn
 
 class NullColumn(FormatColumn):
     ch_type = 'Null'
-    format = '<b'
+    format = 'B'
 
     @property
     def size(self):
         return 1
 
-    def write(self, value, buf):
-        self._write(1, buf)
-
-    def read(self, buf):
-        self._read(buf)
+    def after_read_item(self, buf):
+        return None
