@@ -1,14 +1,16 @@
-import six
 
 from .. import errors
 from ..reader import read_binary_str, read_binary_str_fixed_len
 from ..writer import write_binary_str, write_binary_str_fixed_len
-from .base import Column
+from ..util import compat
+from .base import CustomItemColumn
 
 
-class String(Column):
+class String(CustomItemColumn):
     ch_type = 'String'
-    py_types = six.string_types
+    py_types = compat.string_types
+
+    # TODO: pass user encoding here
 
     def read(self, buf):
         return read_binary_str(buf)
@@ -26,9 +28,9 @@ class String(Column):
 class FixedString(String):
     ch_type = 'FixedString'
 
-    def __init__(self, length):
+    def __init__(self, length, **kwargs):
         self.length = length
-        super(FixedString, self).__init__()
+        super(FixedString, self).__init__(**kwargs)
 
     def read(self, buf):
         return read_binary_str_fixed_len(buf, self.length).strip('\x00')
