@@ -18,7 +18,8 @@ DBMS_DEFAULT_TIMEOUT_SEC = 300
 DBMS_DEFAULT_SYNC_REQUEST_TIMEOUT_SEC = 5
 
 DEFAULT_COMPRESS_BLOCK_SIZE = 1048576
+DEFAULT_INSERT_BLOCK_SIZE = 1048576
 
 DBMS_NAME = 'ClickHouse'
-CLIENT_NAME = 'pyclient'
+CLIENT_NAME = 'python-driver'
 CLIENT_VERSION = 54276
